@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2020 Teunis van Beelen
+# Copyright (c) 2020 - 2023 Teunis van Beelen
 # All rights reserved.
 #
 # Email: teuniz@protonmail.com
@@ -32,7 +32,6 @@
 import sys
 import io
 import os
-import string
 import array
 from collections import namedtuple
 import numpy as np
@@ -167,7 +166,7 @@ class EDFreader:
   EDFLIB_PHYSMIN_IS_PHYSMAX         = -25
   EDFLIB_DATARECORD_SIZE_TOO_BIG    = -26
 
-  EDFLIB_VERSION = 106
+  EDFLIB_VERSION = 107
 
 # max size of annotationtext
   __EDFLIB_WRITE_MAX_ANNOTATION_LEN = 40
@@ -218,7 +217,7 @@ class EDFreader:
     try:
       self.__file_in = open(path, "rb")
     except OSError as e:
-      raise EDFexception("Can not open file for reading: %s" %(e.strerror))
+      raise EDFexception("Cannot open file for reading: %s" %(e.strerror))
 
     self.__err = self.__checkEDFheader()
     if self.__err:
@@ -1010,6 +1009,8 @@ class EDFreader:
               n = 0
               continue
           n += 1
+    if error != 0:
+      return 9
     return 0
 
 ################################################################################
@@ -1142,19 +1143,26 @@ class EDFreader:
 
     if self.__edf:
       self.__filetype = self.EDFLIB_FILETYPE_EDF
-      if self.__reserved[:5] == "EDF+C":
+      if self.__reserved[:44] == "EDF+C                                       ":
         self.__edfplus = 1
+        self.__discontinuous = 0
         self.__filetype = self.EDFLIB_FILETYPE_EDFPLUS
-      if self.__reserved[:5] == "EDF+D":
+      elif self.__reserved[:44] == "EDF+D                                       ":
         self.__edfplus = 1
         self.__discontinuous = 1
         self.__filetype = self.EDFLIB_FILETYPE_EDFPLUS
+      elif self.__reserved[:44] == "                                            ":
+        self.__edfplus = 0
+        self.__discontinuous = 0
+      else:
+        return -99
     if self.__bdf:
       self.__filetype = self.EDFLIB_FILETYPE_BDF
-      if self.__reserved[:5] == "BDF+C":
+      if self.__reserved[:44] == "BDF+C                                       ":
         self.__bdfplus = 1
+        self.__discontinuous = 0
         self.__filetype = self.EDFLIB_FILETYPE_BDFPLUS
-      if self.__reserved[:5] == "BDF+D":
+      if self.__reserved[:44] == "BDF+D                                       ":
         self.__bdfplus = 1
         self.__discontinuous = 1
         self.__filetype = self.EDFLIB_FILETYPE_BDFPLUS
@@ -1611,7 +1619,7 @@ class EDFreader:
       self.__plus_startdate = str128[0 : i].decode("ascii")
 
       if (str80[p] == ord('X')) and (str80[p + 1] == ord(' ')):
-        plus_admincode = ""
+        self.__plus_admincode = ""
         p += 2
       else:
         for i in range(0, 80 - p):
@@ -1624,7 +1632,7 @@ class EDFreader:
         self.__plus_admincode = str128[0 : i].decode("ascii")
 
       if (str80[p] == ord('X')) and (str80[p + 1] == ord(' ')):
-        plus_technician = ""
+        self.__plus_technician = ""
         p += 2
       else:
         for i in range(0, 80 - p):
@@ -1637,7 +1645,7 @@ class EDFreader:
         self.__plus_technician = str128[0 : i].decode("ascii")
 
       if (str80[p] == ord('X')) and (str80[p + 1] == ord(' ')):
-        plus_equipment = ""
+        self.__plus_equipment = ""
         p += 2
       else:
         for i in range(0, 80 - p):
