@@ -1,6 +1,6 @@
 #############################################################################
 #
-# Copyright (c) 2020 Teunis van Beelen
+# Copyright (c) 2020 - 2023 Teunis van Beelen
 # All rights reserved.
 #
 # Email: teuniz@protonmail.com
@@ -31,9 +31,6 @@
 
 import sys
 import io
-import os
-import string
-import array
 from collections import namedtuple
 import numpy as np
 from datetime import datetime
@@ -108,10 +105,10 @@ class EDFwriter:
   https://www.ti.com/general/docs/lit/getliterature.tsp?baseLiteratureNumber=sbaa042
 
   note: An EDF file usually contains multiple so-called datarecords. One datarecord usually has a duration of one second (this is the default but it is not mandatory!).
-  In that case a file with a duration of five minutes contains 300 datarecords. The duration of a datarecord can be freely choosen but, if possible, use values from
+  In that case a file with a duration of five minutes contains 300 datarecords. The duration of a datarecord can be freely chosen but, if possible, use values from
   0.1 to 1 second for easier handling. Just make sure that the total size of one datarecord, expressed in bytes, does not exceed 10MByte (15MBytes for BDF(+)).
 
-  The RECOMMENDATION of a maximum datarecordsize of 61440 bytes in the EDF and EDF+ specification was usefull in the time people were still using DOS as their main operating system.
+  The RECOMMENDATION of a maximum datarecordsize of 61440 bytes in the EDF and EDF+ specification was useful in the time people were still using DOS as their main operating system.
   Using DOS and fast (near) pointers (16-bit pointers), the maximum allocatable block of memory was 64KByte.
   This is not a concern anymore so the maximum datarecord size now is limited to 10MByte for EDF(+) and 15MByte for BDF(+). This helps to accommodate for higher samplingrates
   used by modern Analog to Digital Converters.
@@ -165,7 +162,7 @@ class EDFwriter:
   EDFLIB_PHYSMIN_IS_PHYSMAX         = -25
   EDFLIB_DATARECORD_SIZE_TOO_BIG    = -26
 
-  EDFLIB_VERSION = 106
+  EDFLIB_VERSION = 107
 
 # max size of annotationtext
   __EDFLIB_WRITE_MAX_ANNOTATION_LEN = 40
@@ -236,7 +233,7 @@ class EDFwriter:
     try:
       self.__file_out = open(self.__path, "wb")
     except OSError as e:
-      raise EDFexception("Can not open file for writing: %s" %(e.strerror))
+      raise EDFexception("Cannot open file for writing: %s" %(e.strerror))
 
     if self.__filetype == self.EDFLIB_FILETYPE_EDFPLUS:
       self.__edf = 1
@@ -811,8 +808,6 @@ class EDFwriter:
     if self.__status_ok == 0:
       return -1
 
-    eq_sf = 1
-
     self.__recordsize = 0
 
     str_ = bytearray(256)
@@ -834,10 +829,6 @@ class EDFwriter:
 
       self.__recordsize += self.__param_smp_per_record[i]
 
-      if i > 0:
-        if self.__param_smp_per_record[i] != self.__param_smp_per_record[i-1]:
-          eq_sf = 0
-
     if self.__edf != 0:
       self.__recordsize *= 2
       self.__recordsize += self.__total_annot_bytes
@@ -877,8 +868,7 @@ class EDFwriter:
     else:
       rest = 63
 
-    self.__plus_patientcode.lstrip(" ")
-    self.__plus_patientcode.rstrip(" ")
+    self.__plus_patientcode = self.__plus_patientcode.strip()
     l = len(self.__plus_patientcode)
     if (l != 0) and (rest > 0):
       str_ = bytearray(self.__plus_patientcode, encoding="latin_1")
@@ -919,8 +909,7 @@ class EDFwriter:
       %(self.__plus_birthdate_day, month_str[self.__plus_birthdate_month - 1], self.__plus_birthdate_year), encoding="ascii")
       p += 12
 
-    self.__plus_patient_name.lstrip(" ")
-    self.__plus_patient_name.rstrip(" ")
+    self.__plus_patient_name = self.__plus_patient_name.strip()
     l = len(self.__plus_patient_name)
     if (l != 0) and (rest > 0):
       str_ = bytearray(self.__plus_patient_name, encoding="latin_1")
@@ -943,8 +932,7 @@ class EDFwriter:
       p += 2
       rest -= 1
 
-    self.__plus_patient_additional.lstrip(" ")
-    self.__plus_patient_additional.rstrip(" ")
+    self.__plus_patient_additional = self.__plus_patient_additional.strip()
     l = len(self.__plus_patient_additional)
     if (l != 0) and (rest > 0):
       str_ = bytearray(self.__plus_patient_additional, encoding="latin_1")
@@ -974,8 +962,7 @@ class EDFwriter:
     p = 22
     rest = 50
 
-    self.__plus_admincode.lstrip(" ")
-    self.__plus_admincode.rstrip(" ")
+    self.__plus_admincode = self.__plus_admincode.strip()
     l = len(self.__plus_admincode)
     if (l != 0) and (rest > 0):
       str_ = bytearray(self.__plus_admincode, encoding="latin_1")
@@ -998,8 +985,7 @@ class EDFwriter:
       p += 2
       rest -= 1
 
-    self.__plus_technician.lstrip(" ")
-    self.__plus_technician.rstrip(" ")
+    self.__plus_technician = self.__plus_technician.strip()
     l = len(self.__plus_technician)
     if (l != 0) and (rest > 0):
       str_ = bytearray(self.__plus_technician, encoding="latin_1")
@@ -1022,8 +1008,7 @@ class EDFwriter:
       p += 2
       rest -= 1
 
-    self.__plus_equipment.lstrip(" ")
-    self.__plus_equipment.rstrip(" ")
+    self.__plus_equipment = self.__plus_equipment.strip()
     l = len(self.__plus_equipment)
     if (l != 0) and (rest > 0):
       str_ = bytearray(self.__plus_equipment, encoding="latin_1")
@@ -1046,8 +1031,7 @@ class EDFwriter:
       p += 2
       rest -= 1
 
-    self.__plus_recording_additional.lstrip(" ")
-    self.__plus_recording_additional.rstrip(" ")
+    self.__plus_recording_additional = self.__plus_recording_additional.strip()
     l = len(self.__plus_recording_additional)
     if (l != 0) and (rest > 0):
       str_ = bytearray(self.__plus_recording_additional, encoding="latin_1")
@@ -1212,7 +1196,6 @@ class EDFwriter:
 
 # writes the annotations to the file
   def __write_annotations(self):
-    err = 0
     datrecs = 0
 
     str_ = bytearray(self.__EDFLIB_ANNOTATION_BYTES)
@@ -1281,9 +1264,9 @@ class EDFwriter:
           p += n
       str_[p] = 20
       p += 1
-      annot2.description.lstrip(" ")
-      annot2.description.rstrip(" ")
-      ba_tmp = bytearray(annot2.description, encoding="utf-8")
+      tmp_str = str(annot2.description)
+      tmp_str = tmp_str.strip()
+      ba_tmp = bytearray(tmp_str, encoding="utf-8")
       l = self.__strlen(ba_tmp)
       if l > self.__EDFLIB_WRITE_MAX_ANNOTATION_LEN:
         l = self.__EDFLIB_WRITE_MAX_ANNOTATION_LEN
